SystemOrganization addCategory: #'XML-ParserGemstoneCompatibility'!

Object subclass: #XMLParserGemstoneCompatibility
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XML-ParserGemstoneCompatibility'!

!XMLParserGemstoneCompatibility commentStamp: 'monty 4/28/2017 21:56' prior: 0!
Used in development to copy String extension methods to CharacterCollection.!

!XMLParserGemstoneCompatibility class methodsFor: 'private' stamp: 'monty 1/28/2018 01:15'!
copyXMLGSExtensionMethods
	"
	self copyXMLGSExtensionMethods
	"
	(String selectorsInProtocol: #'*XML-Parser') do: [:each |
		CharacterCollection
			compile: (String sourceCodeAt: each)
			classified: #'*XML-ParserGemstoneCompatibility'].! !

XMLFileReadStreamFactory subclass: #XMLGsFileReadStreamFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XML-ParserGemstoneCompatibility'!

!XMLGsFileReadStreamFactory commentStamp: 'monty 3/13/2016 23:23' prior: 0!
A GsFile read stream factory. This stream is preferred for Gemstone because it does no decoding and returns byte characters so XMLParser can do its own decoding.!

!XMLGsFileReadStreamFactory class methodsFor: 'instance creation' stamp: 'monty 7/6/2016 02:33'!
basicOnPath: aPathString
	^ (XMLClassFinder classNamed: #GsFile)
		open: aPathString
		mode: 'rb' "binary to avoid CRLF<->LF conversions on Windows"
		onClient: false "use server files by default"! !

!XMLGsFileReadStreamFactory class methodsFor: 'testing' stamp: 'monty 7/6/2016 02:40'!
isSupportedImplementation
	^ XMLClassFinder hasClassNamed: #GsFile! !

!GsFile methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 9/19/2016 14:08'!
isStream
	"needed so #parse: and similar messages can accept GsFile arguments"
	^ true! !

!GsFile methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 9/19/2016 14:18'!
upToEnd
	"needed for compatibility with XMLReadStreamAdapter
	(GsFile>>#contents works like #upToEnd, so this is OK)"
	^ self contents! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
asXMLEscapedString
	"returns a copy of self with &, <, and > escaped with &amp;, &lt;, and &gt;"
	| stream |

	stream := (self class new: self size) writeStream.
	"to:do: for performance"
	1 to: self size do: [:i | | nextChar |
		(nextChar := self at: i) == $<
			ifTrue: [stream nextPutAll: '&lt;']
			ifFalse: [
				nextChar == $> "needed to escape ]]> in PCDATA"
					ifTrue: [stream nextPutAll: '&gt;']
					ifFalse: [
						nextChar == $&
							ifTrue: [stream nextPutAll: '&amp;']
							ifFalse: [stream nextPut: nextChar]]]].
	^ stream contents.! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
asXMLFileHandle
	^ XMLFileHandle path: self! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
asXMLHTTPRequest
	^ XMLHTTPRequest url: self! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
asXMLStreamConverter
	^ XMLStreamConverter newForEncoding: self! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
asXMLString
	"will be deprecated; use #asXMLStringNode instead"

	^ self asXMLStringNode! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
asXMLStringNode
	^ XMLString string: self! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
asXMLURI
	^ XMLURI fromString: self! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
expandWithXMLNamespaceURI: aURI
	"optimized"
	aURI size == 0
		ifTrue: [^ self]
		ifFalse: [^ 'Q{', aURI, '}', self]! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
isXMLNCName
	"optimized"
	self size == 0
		ifTrue: [^ false].
	(self at: 1) isXMLNCNameStartChar
		ifFalse: [^ false].
	2 to: self size do: [:i |
		(self at: i) isXMLNCNameChar
			ifFalse: [^ false]].
	^ true.! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
isXMLNSAttributeName
	"optimized"
	self size >= 5
		ifFalse: [^ false].
	(self at: 1) == $x
		ifFalse: [^ false].
	(self at: 2) == $m
		ifFalse: [^ false].
	(self at: 3) == $l
		ifFalse: [^ false].
	(self at: 4) == $n
		ifFalse: [^ false].
	(self at: 5) == $s
		ifFalse: [^ false].
	self size == 5
		ifTrue: [^ true].
	^ (self at: 6) == $:.! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
isXMLName
	"optimized"
	self size == 0
		ifTrue: [^ false].
	(self at: 1) isXMLNameStartChar
		ifFalse: [^ false].
	2 to: self size do: [:i |
		(self at: i) isXMLNameChar
			ifFalse: [^ false]].
	^ true.! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
isXMLNmtoken
	"optimized"
	self size == 0
		ifTrue: [^ false].
	1 to: self size do: [:i |
		(self at: i) isXMLNameChar
			ifFalse: [^ false]].
	^ true.! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
isXMLQualifiedOrLocalName: aQualifiedOrLocalName
	"returns true if self and aQualifiedOrLocalName are the
	same QName or if self is a QName and aQualifiedOrLocalName
	is the local part, or if they are the same NCName."
	| i |

	i := aQualifiedOrLocalName size.
	self size to: 1 by: -1 do: [:j |
		i == 0
			ifTrue: [^ (self at: j) == $:].
		"avoid #== for compatibility with pre-Spur VMs where wide chars
		aren't an immediate type"
		(aQualifiedOrLocalName at: i) = (self at: j)
			ifFalse: [^ false].
		i := i - 1].
	^ i == 0.! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
isXMLReservedAttributeName
	"optimized"
	self size > 3
		ifFalse: [^ false].
	(self at: 1) == $x
		ifFalse: [^ false].
	(self at: 2) == $m
		ifFalse: [^ false].
	^ (self at: 3) == $l.! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
isXMLWhitespace
	"optimized"
	self size == 0
		ifTrue: [^ false].
	1 to: self size do: [:i |
		(self at: i) isXMLWhitespace
			ifFalse: [^ false]].
	^ true.! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
parseXML
	^ XMLDOMParser parse: self! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
qualifyWithXMLPrefix: aPrefix
	"optimized"
	aPrefix size == 0
		ifTrue: [^ self]
		ifFalse: [^ (aPrefix copyWith: $:), self]! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
xmlCopyWithoutWhitespace
	^ self reject: [:each | each isXMLWhitespace]! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
xmlLocalNameAfterPrefix
	^ self xmlLocalNameAfterPrefix: self xmlPrefixBeforeLocalName! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
xmlLocalNameAfterPrefix: aPrefix
	"optimized"
	| prefixSize |

	(prefixSize := aPrefix size) == 0
		ifTrue: [^ self]
		ifFalse: [^ self copyFrom: prefixSize + 2 to: self size]! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
xmlPrefixBeforeLocalName
	"optimized"
	| i |

	i := self size.
	[i == 0]
		whileFalse: [
			((self at: i) == $:)
				ifTrue: [^ (self copyFrom: 1 to: i - 1)].
			i := i - 1].
	^ ''.! !

!CharacterCollection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
xmlPrefixBeforeLocalName: aLocalName
	"optimized"
	| prefixSize |

	(prefixSize := self size - aLocalName size - 1) > 0
		ifTrue: [^ self copyFrom: 1 to: prefixSize]
		ifFalse: [^ '']! !

XMLReentrantMutex subclass: #XMLTransientReentrantMutex
	instanceVariableNames: 'transientRecursionLock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XML-ParserGemstoneCompatibility'!

!XMLTransientReentrantMutex commentStamp: 'monty 10/9/2016 05:28' prior: 0!
This class is an implementation that uses Gemstone's TransientRecursionLock to implement a reentrant mutex. These are not persistent.!

!XMLTransientReentrantMutex class methodsFor: 'testing' stamp: 'monty 10/7/2016 02:44'!
isSupportedImplementation
	^ XMLClassFinder hasClassNamed: #TransientRecursionLock! !

!XMLTransientReentrantMutex methodsFor: 'mutual exclusion' stamp: 'monty 10/5/2016 22:30'!
critical: aBlock
	^ transientRecursionLock critical: aBlock! !

!XMLTransientReentrantMutex methodsFor: 'initialization' stamp: 'monty 10/5/2016 22:19'!
initialize
	super initialize.

	transientRecursionLock :=
		(XMLClassFinder classNamed: #TransientRecursionLock) new.! !

!PositionableStream methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/7/2018 07:54'!
isBinary
	"needed for GZipReadStream and Zinc"
	^ self _collection class == ByteArray! !

!Collection methodsFor: '*XML-ParserGemstoneCompatibility' stamp: 'monty 2/18/2016 04:55'!
capacity
	^ self size! !

XMLKeyValueCache subclass: #XMLTransientKeyValueCache
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XML-ParserGemstoneCompatibility'!

!XMLTransientKeyValueCache commentStamp: 'monty 10/9/2016 18:14' prior: 0!
This class is a key-value cache implementation for Gemstone that uses a transient internal collection.!

!XMLTransientKeyValueCache class methodsFor: 'testing' stamp: 'monty 10/9/2016 03:18'!
isSupportedImplementation
	^ XMLReentrantMutex hasSupportedImplementation
		and: [XMLClassFinder hasClassNamed: #TransientValue]! !

!XMLTransientKeyValueCache methodsFor: 'accessing' stamp: 'monty 10/9/2016 03:15'!
collection
	^ collection value
		ifNil: [
			collection
				value: self collectionClass new;
				value]! !

!XMLTransientKeyValueCache methodsFor: 'initialization' stamp: 'monty 10/9/2016 02:58'!
setCollection: aKeyValueCollection
	collection :=
		(XMLClassFinder classNamed: #TransientValue) value:
			aKeyValueCollection! !

XMLFileWriteStreamFactory subclass: #XMLGsFileWriteStreamFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XML-ParserGemstoneCompatibility'!

!XMLGsFileWriteStreamFactory commentStamp: 'monty 3/13/2016 23:24' prior: 0!
A GsFile write stream factory. This stream is preferred for Gemstone because it does no encoding and accepts byte characters so XMLParser can do its own encoding.!

!XMLGsFileWriteStreamFactory class methodsFor: 'instance creation' stamp: 'monty 7/6/2016 02:34'!
basicOnPath: aPathString
	^ (XMLClassFinder classNamed: #GsFile)
		open: aPathString
		mode: 'wb' "binary to avoid CRLF<->LF conversions on Windows"
		onClient: false "use server files by default"! !

!XMLGsFileWriteStreamFactory class methodsFor: 'testing' stamp: 'monty 7/6/2016 02:40'!
isSupportedImplementation
	^ XMLClassFinder hasClassNamed: #GsFile! !
